package com.bweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighCouponCode;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighCouponCodeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @Auther: 胡锐
 * @Description: 卡卷销售码
 * @Date: 2021/3/22 19:39
 */
@Controller
@RequestMapping(value = "/couponCode")
@Api(value = "卡卷销售码接口")
public class HighCouponCodeController {

    private static Logger log = LoggerFactory.getLogger(HighCouponCodeController.class);

    @Resource
    private HighCouponCodeService highCouponCodeService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value="/getCouponCodeList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "销售码列表")
    public ResponseData getCouponCodeList(@RequestParam(name = "couponId", required = true) Long couponId,
                                          @RequestParam(name = "status", required = false) Integer status,
                                          @RequestParam(name = "salesCode", required = false) String salesCode,
                                          @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                          @RequestParam(name = "pageSize", required = true) Integer pageSize) {
        try {
            Map<String, Object> map = new HashMap<>();
            map.put("couponId", couponId);
            map.put("status", status);
            map.put("salesCode", salesCode);

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highCouponCodeService.getCouponCodeList(map)));
        } catch (Exception e) {
            log.error("HighCouponController -> getCouponCodeList() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value="/useCouponCode",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "使用卡卷码")
    public ResponseData useCouponCode(@RequestBody String reqBody, HttpServletRequest request) {
        try {
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();
            if (userInfoModel.getMerchantStore() == null) {
                log.error("HighMerchantController -> useCouponCode() error!","该主角色没有权限");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.MENU_TREE_HAS_NOT_ERROR, "");
            }
            JSONObject jsonObject = JSONObject.parseObject(reqBody);
            String code = jsonObject.getString("code");
            if (StringUtils.isBlank(code)) {
                log.error("HighMerchantStoreController -> useCouponCode() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            highCouponCodeService.useCouponCode(code, userInfoModel);

            return ResponseMsgUtil.success("操作成功");
        } catch (Exception e) {
            log.error("HighCouponController -> useCouponCode() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
